==> dpkg_1.4.0.23.2.tar.gz: dpkg-1.4.0.23.2/acconfig.h <==
/* Additional tests: */

/* The name of the package being compiled */
#define PACKAGE ""

/* The version of the package */
#define VERSION ""

/* Define if inline functions a la GCC are available.  */
#undef HAVE_INLINE

/* Define if sysinfo is available.  */
#undef HAVE_SYSINFO

/* Define if __NR_sysinfo is available.  */
#undef HAVE_NRSYSINFO

/* Define if inline functions a la GCC are available.  */
#undef HAVE_ALPHASORT_DECLARATION

/* Define if function attributes a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_ATTRIB

/* Define if constant functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_CONST

/* Define if nonreturning functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_NORETURN

/* Define if printf-format argument lists a la GCC are available.  */
#undef HAVE_GNUC25_PRINTFFORMAT

/* Set this to the canonical Debian architecture string for this CPU type. */
#undef ARCHITECTURE

/* Set this to 1 to build new archives by default. */
#define BUILDOLDPKGFORMAT 0

/* Set this string to append something to the version number. */
#define ARCHBINFMT ""

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

==> dpkg_1.6.15.tar.gz: dpkg-1.6.15/acconfig.h <==
/* Additional tests: */

/* The name of the package being compiled */
#define PACKAGE ""

/* The version of the package */
#define VERSION ""

/* Define if inline functions a la GCC are available.  */
#undef HAVE_INLINE

/* Define if sysinfo is available.  */
#undef HAVE_SYSINFO

/* Define if __NR_sysinfo is available.  */
#undef HAVE_NRSYSINFO

/* Define if inline functions a la GCC are available.  */
#undef HAVE_ALPHASORT_DECLARATION

/* Define if function attributes a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_ATTRIB

/* Define if constant functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_CONST

/* Define if nonreturning functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_NORETURN

/* Define if printf-format argument lists a la GCC are available.  */
#undef HAVE_GNUC25_PRINTFFORMAT

/* Set this to the canonical Debian architecture string for this CPU type. */
#undef ARCHITECTURE

/* Set this to 1 to build new archives by default. */
#define BUILDOLDPKGFORMAT 0

/* Set this string to append something to the version number. */
#define ARCHBINFMT ""

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Defined to $(localstatedir) dir location */
#undef LOCALSTATEDIR

/* Defined to the $(libdir) location */
#undef LLIBDIR

/* Is sysinfo() persent */
#undef HAVE_SYSINFO

/* Do we have proper memory information in struct sysinfo */
#undef MEMINFO_IN_SYSINFO

/* Define the ptrdiff_t type if your system doesn't have it */
#undef ptrdiff_t
